## ---- echo = FALSE, results = "asis"--------------------------------------------------------------------------------------------
options(width = 130)
set.seed(44)

## ---- echo = FALSE--------------------------------------------------------------------------------------------------------------
htmltools::img(src = knitr::image_uri("ClassifyRprocedure.png"), 
               style = 'margin-left: auto;margin-right: auto')

## ---- message = FALSE-----------------------------------------------------------------------------------------------------------
library(ClassifyR)
data(melanomaResponse) # Replace with real dataset soon. This is rnorm.
measurements[1:5, 1:5]
head(classes)

## ---- tidy = FALSE--------------------------------------------------------------------------------------------------------------
resubstituteParams <- ResubstituteParams(nFeatures = 2:10,
                                         performanceType = "balanced error",
                                         better = "lower")
DMresults <- runTests(measurements, classes, "Melanoma", "Different Means",
                      validation = "leaveOut", leave = 1,
                      params = list(SelectParams(limmaSelection, "Moderated t Statistic",
                                                 resubstituteParams = resubstituteParams),
                                    TrainParams(DLDAtrainInterface),
                                    PredictParams(DLDApredictInterface,
                                                  getClasses = function(result)
                                                               result[["class"]])),
                      verbose = 1)
DMresults

## ---- fig.height = 8, fig.width = 8, results = "hold", message = FALSE----------------------------------------------------------
selectionPercentages <- distribution(DMresults, plot = FALSE)
mostChosen <- names(sort(selectionPercentages, decreasing = TRUE)[1])
bestProteinPlot <- plotFeatureClasses(measurements, classes, mostChosen, dotBinWidth = 0.1,
                                      xAxisLabel = "Standardised Expression")

## -------------------------------------------------------------------------------------------------------------------------------
DMresults <- calcCVperformance(DMresults, "balanced error")
DMresults
performance(DMresults)

## ---- tidy = FALSE--------------------------------------------------------------------------------------------------------------
DDresults <- runTests(measurements, classes, "Melanoma", "Differential Distribution",
                      validation = "leaveOut", leave = 1,
                      params = list(SelectParams(KullbackLeiblerSelection,
                                                 resubstituteParams = resubstituteParams),
                                    TrainParams(naiveBayesKernel),
                                    PredictParams(predictor = NULL, getClasses = function(result) result,
                                                  weighted = "weighted", weight = "height difference",
                                                  returnType = "both")),
                                verbose = 1)
DDresults

## ---- fig.width = 10, fig.height = 7--------------------------------------------------------------------------------------------
library(grid)
DMresults <- calcCVperformance(DMresults, "sample error")
DDresults <- calcCVperformance(DDresults, "sample error")
resultsList <- list(Abundance = DMresults, Distribution = DDresults)
errorPlot <- samplesMetricMap(resultsList, metric = "error", plot = FALSE)
grid.draw(errorPlot)

## -------------------------------------------------------------------------------------------------------------------------------
rankOverlaps <- rankingPlot(list(DDresults), topRanked = 1:10, xLabelPositions = 1:10,
                            lineColourVariable = "None", pointTypeVariable = "None",
                            columnVariable = "None", plot = FALSE)
rankOverlaps

## ---- fig.height = 5, fig.width = 6---------------------------------------------------------------------------------------------
ROCcurves <- ROCplot(list(DDresults), fontSizes = c(24, 12, 12, 12, 12))

## -------------------------------------------------------------------------------------------------------------------------------
SVMresults <- runTests(measurements, classes, "Melanoma", "Tuned SVM",
                       validation = "leave", leave = 1,
                       params = list(SelectParams(limmaSelection, resubstituteParams = resubstituteParams),
                                     TrainParams(SVMtrainInterface, kernel = "linear",
                                                 resubstituteParams = resubstituteParams,
                                                 tuneParams = list(cost = c(0.01, 0.1, 1, 10))),
                                     PredictParams(SVMpredictInterface,
                                                   getClasses = function(result) result))
                       )

## -------------------------------------------------------------------------------------------------------------------------------
length(tunedParameters(SVMresults))
tunedParameters(SVMresults)[1:3]

## ---- echo = FALSE--------------------------------------------------------------------------------------------------------------
htmltools::img(src = knitr::image_uri("providedSelection.png"), 
               style = 'margin-left: auto;margin-right: auto')

## ---- echo = FALSE--------------------------------------------------------------------------------------------------------------
htmltools::img(src = knitr::image_uri("providedClassifiers.png"), 
               style = 'margin-left: auto;margin-right: auto')

## ---- echo = FALSE--------------------------------------------------------------------------------------------------------------
htmltools::img(src = knitr::image_uri("functionRules.png"), 
               style = 'margin-left: auto;margin-right: auto')

